@@ -1,5 +1,6 @@
+use hyper::header::HeaderValue;
 use std::{
-    convert::TryInto,
+    convert::{TryFrom, TryInto},
     sync::atomic::{AtomicU64, Ordering::Relaxed},
     time::{Duration, SystemTime, UNIX_EPOCH},
     u64,
@@ -26,9 +27,10 @@ pub fn total_download_duration(t: SystemTime) -> Duration {
 
 pub(super) const REQUEST_ID_HEADER: &str = "X-ReqId";
 
-pub(super) fn get_req_id(tn: SystemTime, index: usize) -> String {
+pub(super) fn get_req_id(tn: SystemTime, index: usize) -> HeaderValue {
     let start_time: u64 = START_TIME.load(Relaxed);
     let end_time: u128 = tn.duration_since(UNIX_EPOCH).map_or(0, |n| n.as_nanos());
     let delta: u128 = end_time - u128::from(start_time) * 1000 * 1000;
-    format!("r{}-{}-{}", start_time, delta, index)
+    HeaderValue::try_from(format!("r{}-{}-{}", start_time, delta, index))
+        .expect("Unexpected invalid header value")
 }
